TIKTOKEN_MODEL_MAPPING = {
    "gpt-4": "cl100k_base",
    "gpt-4-32k": "cl100k_base",
    "gpt-4-0125-preview": "cl100k_base",
    "gpt-4-1106-preview": "cl100k_base",
    "gpt-4-1106-vision-preview": "cl100k_base",
    "gpt-4o": "0200k_base",
    "gpt-4o-mini": "0200k_base",
}

SERVICE_PROVIDERS = {
    "ANTHROPIC": "Anthropic",
    "ARCH": "Arch",
    "AZURE": "Azure",
    "CHROMA": "Chroma",
    "CREWAI": "CrewAI",
    "DEEPSEEK": "DeepSeek",
    "DSPY": "DSPy",
    "GROQ": "Groq",
    "LANGCHAIN": "Langchain",
    "LANGCHAIN_COMMUNITY": "Langchain Community",
    "LANGCHAIN_CORE": "Langchain Core",
    "LANGGRAPH": "Langgraph",
    "LITELLM": "Litellm",
    "LLAMAINDEX": "LlamaIndex",
    "OPENAI": "OpenAI",
    "PINECONE": "Pinecone",
    "COHERE": "Cohere",
    "PPLX": "Perplexity",
    "QDRANT": "Qdrant",
    "WEAVIATE": "Weaviate",
    "OLLAMA": "Ollama",
    "VERTEXAI": "Vertex AI",
    "GEMINI": "Gemini",
    "MISTRAL": "Mistral",
    "EMBEDCHAIN": "Embedchain",
    "AUTOGEN": "Autogen",
    "XAI": "XAI",
    "MONGODB": "MongoDB",
    "AWS_BEDROCK": "AWS Bedrock",
    "CEREBRAS": "Cerebras",
    "MILVUS": "Milvus",
    "GRAPHLIT": "Graphlit",
    "PHIDATA": "Phidata",
    "AGNO": "Agno",
}

LANGTRACE_ADDITIONAL_SPAN_ATTRIBUTES_KEY = "langtrace_additional_attributes"
